@@ -1,6 +1,6 @@
 from . import analysis
 from . import datasets
 from . import downloads
-from . import evaluation
 from . import loader
-from . import splits
\ No newline at end of file
+from . import splits
+from . import asdasd
\ No newline at end of file
